{
Client Access Objects 1.5

caoDataQueueAttr component

(c) 1998, 1999 Steven P. Goldsmith
All Rights Reserved

The cwbDataQueueAttr automation object is used for setting the attributes of a
new data queue or retrieving the attributes of an existing data queue.  For
example, the maximum record length and the order in which records are read from
the queue can be accessed.  This object is used in conjunction with the
cwbdqCreate and cwbdqGetQueueAttr methods of the cwbDataQueue object.

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 1, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

sgoldsmith@home.com
http://members.home.net/sgoldsmith/
}

unit caoDataQueueAttr;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,

  // Import type library "Client Access Object Library" before installing.

  Cwbautsv_TLB;

type

  // caoDataQueueAttr exception object

  EcaoDataQueueAttr = class(Exception);

  TcaoAuthority = (
    caodqAll,
    caodqExclude,
    caodqChange,
    caodqUse,
    caodqLibcrtaut);

  TcaoQueueOrder = (
    caodqSeqLifo,
    caodqSeqFifo,
    caodqSeqKeyed);

  TcaoDataQueueAttr = class(TComponent)
  private
    { Private declarations }
    FReturnCode: integer;
    FSetupCalled: boolean;
    Fauthority: TcaoAuthority;
    Fdescription: WideString;
    FforceToStorage: WordBool;
    FkeySize: Smallint;
    FmaxRecordLength: Integer;
    Forder: TcaoQueueOrder;
    FsenderID: WordBool;
    FcwbDataQueueAttr: cwbDataQueueAttr;
    function GetAuthority: TcaoAuthority;
    procedure SetAuthority(Auth: TcaoAuthority);
    function GetDescription: WideString;
    procedure SetDescription(Desc: WideString);
    function GetForceToStorage: WordBool;
    procedure SetForceToStorage(Force: WordBool);
    function GetKeySize: SmallInt;
    procedure SetKeySize(KeySiz: SmallInt);
    function GetMaxRecordLength: Integer;
    procedure SetMaxRecordLength(RecLen: Integer);
    function GetOrder: TcaoQueueOrder;
    procedure SetOrder(O: TcaoQueueOrder);
    function GetSenderID: WordBool;
    procedure SetSenderID(ID: WordBool);
  protected
    { Protected declarations }
    function ResultCodeText: string; virtual;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    procedure Setup; virtual;
  published
    { Published declarations }
    property ReturnCode: integer read FReturnCode default cwbOK;
    property authority: TcaoAuthority read GetAuthority write SetAuthority default caodqLibcrtAut;
    property description: WideString read GetDescription write SetDescription;
    property forceToStorage: WordBool read GetForceToStorage write SetForceToStorage default false;
    property keySize: Smallint read GetKeySize write SetKeySize default 0;
    property maxRecordLength: Integer read GetMaxRecordLength write SetMaxRecordLength default 1000;
    property order: TcaoQueueOrder read GetOrder write SetOrder default caodqSeqFifo;
    property senderID: WordBool read GetSenderID write SetSenderID default false;
    property OleObject: cwbDataQueueAttr read FcwbDataQueueAttr;
  end;

implementation

{
Create OLE object and initilize properties.
}

constructor TcaoDataQueueAttr.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FcwbDataQueueAttr := CocwbDataQueueAttr.Create;
  FSetupCalled := false;
  Fauthority := caodqLibcrtAut;
  Fdescription := '';
  FforceToStorage := false;
  FkeySize := 0;
  FmaxRecordLength := 1000;
  Forder := caodqSeqFifo;
  FsenderID := false
end;

{
Return formatted result code text.
}

function TcaoDataQueueAttr.ResultCodeText: string;
begin
  Result := Format('Result code %d',[FReturnCode])
end;

{
This property contains the public authority assigned to the data queue.
Possible values are:  cwbdqExclude, cwbdqChange, cwbdqAll, cwbdqUse, and
cwbdqLibcrtaut,  If the authority property is not set before a cwbdqCreate
call, cwbdqLibcrtAut is used.  This is a read/write property.

Get OLE property authority if setup was called.  Otherwise, get private
variable.
}

function TcaoDataQueueAttr.GetAuthority: TcaoAuthority;
begin
  if FSetupCalled then
    case FcwbDataQueueAttr.authority of
      cwbdqAll:
        Result := caodqAll;
      cwbdqExclude:
        Result := caodqExclude;
      cwbdqChange:
        Result := caodqChange;
      cwbdqUse:
        Result := caodqUse;
      cwbdqLibcrtaut:
        Result := caodqLibcrtaut
      else
        Result := caodqLibcrtaut
    end
  else
    Result := Fauthority
end;

{
Set OLE property authority if setup was called. Otherwise, set private variable.
}

procedure TcaoDataQueueAttr.SetAuthority(Auth: TcaoAuthority);
begin
  if FSetupCalled then
    case Auth of
      caodqAll:
        FcwbDataQueueAttr.authority := cwbdqAll;
      caodqExclude:
        FcwbDataQueueAttr.authority := cwbdqExclude;
      caodqChange:
        FcwbDataQueueAttr.authority := cwbdqChange;
      caodqUse:
        FcwbDataQueueAttr.authority := cwbdqUse;
      caodqLibcrtaut:
        FcwbDataQueueAttr.authority := cwbdqLibcrtaut
    end
  else
    Fauthority := Auth
end;

{
This property contains the description of the data queue.  If this property is
not set before a cwbdqCreate call, the description will be blank.  This is a
read/write property.

Get OLE property description if setup was called.  Otherwise, get private
variable.
}

function TcaoDataQueueAttr.GetDescription: WideString;
begin
  if FSetupCalled then
    Result :=  FcwbDataQueueAttr.description
  else
    Result := Fdescription
end;

{
Set OLE property description if setup was called. Otherwise, set private
variable.
}

procedure TcaoDataQueueAttr.SetDescription(Desc: WideString);
begin
  if FSetupCalled then
    FcwbDataQueueAttr.description := Desc
  else
    Fdescription := Desc
end;

{
This property indicates whether or not records will be forced to auxiliary
storage when they are enqueued.  If this property is not set before a
cwbdqCreate call, records are not immediately forced to storage.  This is a
read/write property.

Get OLE property forceToStorage if setup was called.  Otherwise, get private
variable.
}

function TcaoDataQueueAttr.GetForceToStorage: WordBool;
begin
  if FSetupCalled then
    Result :=  FcwbDataQueueAttr.forceToStorage
  else
    Result := FforceToStorage
end;

{
Set OLE property forceToStorage if setup was called. Otherwise, set private
variable.
}

procedure TcaoDataQueueAttr.SetForceToStorage(Force: WordBool);
begin
  if FSetupCalled then
    FcwbDataQueueAttr.forceToStorage := Force
  else
    FforceToStorage := Force
end;

{
This property contains the key size, in bytes.  Valid values are 0 through 256.
If the queue order is cwbdqSeqLifo or cwbdqSeqFifo, the keySize property is not
used.  If this property is not set before a cwbdqCreate call, a key size of
zero is used.  This is a read/write property.

Get OLE property keySize if setup was called.  Otherwise, get private variable.
}

function TcaoDataQueueAttr.GetKeySize: SmallInt;
begin
  if FSetupCalled then
    Result :=  FcwbDataQueueAttr.keySize
  else
    Result := FkeySize
end;

{
Set OLE property keySize if setup was called. Otherwise, set private variable.
}

procedure TcaoDataQueueAttr.SetKeySize(KeySiz: SmallInt);
begin
  if FSetupCalled then
    FcwbDataQueueAttr.keySize := KeySiz
  else
    FkeySize := KeySiz
end;

{
This property contains the maximum record length for the data queue.  Valid
values are 1 through 31,744.  If this property is not set before a cwbdqCreate
call, a maximum length of 1,000 bytes is used.  This is a read/write property.

Get OLE property maxRecordLength if setup was called.  Otherwise, get private
variable.
}

function TcaoDataQueueAttr.GetMaxRecordLength: Integer;
begin
  if FSetupCalled then
    Result :=  FcwbDataQueueAttr.maxRecordLength
  else
    Result := FmaxRecordLength
end;

{
Set OLE property maxRecordLength if setup was called. Otherwise, set private
variable.
}

procedure TcaoDataQueueAttr.SetMaxRecordLength(RecLen: Integer);
begin
  if FSetupCalled then
    FcwbDataQueueAttr.maxRecordLength := RecLen
  else
    FmaxRecordLength := RecLen
end;

{
This property contains the order in which data is read from the data queue.  If
the order is cwbdqSeqLifo, the last record written is the first record read.
If the order is cwbdqSeqFifo, the first record written is the first record
read.  If the order is cwbdqSeqKeyed, the order in which records are read from
the data queue depends on the value of the searchOrder property of the
cwbDataQueueDataAttr object and the key value specified for the cwbdqSetKey
method of the cwbDataQueueDataAttr object.  If multiple records contain the key
which satisfies the searchOrder, a FIFO scheme is used among those records.  If
the order property is not set before a cwbdqCreate call, cwbdqSeqFifo is used.
This is a read/write property.

Get OLE property order if setup was called.  Otherwise, get private
variable.
}

function TcaoDataQueueAttr.GetOrder: TcaoQueueOrder;
begin
  if FSetupCalled then
    case FcwbDataQueueAttr.order of
      cwbdqSeqLifo:
        Result := caodqSeqLifo;
      cwbdqSeqFifo:
        Result := caodqSeqFifo;
      cwbdqSeqKeyed:
        Result := caodqSeqKeyed
      else
        Result := caodqSeqFifo
    end
  else
    Result := Forder
end;

{
Set OLE property order if setup was called. Otherwise, set private variable.
}

procedure TcaoDataQueueAttr.SetOrder(O: TcaoQueueOrder);
begin
  if FSetupCalled then
    case O of
      caodqSeqLifo:
        FcwbDataQueueAttr.order := cwbdqSeqLifo;
      caodqSeqFifo:
        FcwbDataQueueAttr.order := cwbdqSeqFifo;
      caodqSeqKeyed:
        FcwbDataQueueAttr.order := cwbdqSeqKeyed
    end
  else
    Forder := O
end;

{
This property indicates whether or not information about the sender is kept
with each record on the data queue.  If this property is not set before a
cwbdqCreate call, sender information will not be kept with each record.  This
is a read/write property.

Get OLE property senderID if setup was called.  Otherwise, get private
variable.
}

function TcaoDataQueueAttr.GetSenderID: WordBool;
begin
  if FSetupCalled then
    Result :=  FcwbDataQueueAttr.senderID
  else
    Result := FsenderID
end;

{
Set OLE property senderID if setup was called. Otherwise, set private
variable.
}

procedure TcaoDataQueueAttr.SetSenderID(ID: WordBool);
begin
  if FSetupCalled then
    FcwbDataQueueAttr.senderID := ID
  else
    FsenderID := ID
end;

{
This method initializes the cwbDataQueueAttr object.  It must be called before
any other method or before accessing any of the objects properties.
}

procedure TcaoDataQueueAttr.Setup;
begin
  FReturnCode := FcwbDataQueueAttr.cwbdqSetup;
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDataQueueAttr.Create(ResultCodeText);
  FSetupCalled := true;
  // Set OLE properties from variables
  SetAuthority(Fauthority);
  SetDescription(Fdescription);
  SetForceToStorage(FforceToStorage);
  SetKeySize(FkeySize);
  SetmaxRecordLength(FmaxRecordLength);
  SetOrder(Forder);
  SetSenderID(FsenderID)
end;

end.
