{
Client Access Objects 1.5

caoDatabaseConnection component

(c) 1998, 1999 Steven P. Goldsmith
All Rights Reserved

The cwbDatabaseConnection automation object establishes a connection to a data
base server located on an AS/400 system.  When the connection is established,
the cwbDatabaseCatalog, cwbDatabaseDB2, and cwbDatabaseSQL objects can be used
to issue database requests to the AS/400.

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 1, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

sgoldsmith@home.com
http://members.home.net/sgoldsmith/
}

unit caoDatabaseConnection;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  caoErrorMessage,

  // Import type library "Client Access Object Library" before installing.

  Cwbautsv_TLB;

type

  // caoDatabaseConnection exception object

  EcaoDatabaseConnection = class(Exception);

  TcaoCommitmentControl = (
    caodbNone,
    caodbCursorStability,
    caodbChange,
    caodbAll);

  TcaoDateFormat = (
    caodbDateFmtJUL,
    caodbDateFmtMDY,
    caodbDateFmtDMY,
    caodbDateFmtYMD,
    caodbDateFmtUSA,
    caodbDateFmtISO,
    caodbDateFmtJIS,
    caodbDateFmtEUR);

  TcaoDateSeparator = (
    caodbDateSepSlash,
    caodbDateSepDash,
    caodbDateSepPeriod,
    caodbDateSepComma,
    caodbDateSepBlank);

  TcaoDecimalSeparator = (
    caodbDecimalSepPeriod,
    caodbDecimalSepComma);

  TcaoIgnoreDecimalDataError = (
    caodbIgnoreError,
    caodbCorrectError);

  TcaoNamingConvention = (
    caodbPeriodNameConv,
    caodbSlashNameConv);

  TcaoTimeFormat = (
    caodbTimeFmtHMS,
    caodbTimeFmtUSA,
    caodbTimeFmtISO,
    caodbTimeFmtEUR,
    caodbTimeFmtJIS);

  TcaoTimeSeparator = (
    caodbTimeSepColon,
    caodbTimeSepPeriod,
    caodbTimeSepComma,
    caodbTimeSepBlank);

  // TcaoDatabaseConnection component

  TcaoDatabaseConnection = class(TComponent)
  private
    { Private declarations }
    FReturnCode: Integer;
    FActive: Boolean;
    FSetupCalled: Boolean;
    FsystemName: String;
    Fconvert65535: Boolean;
    FcommitmentControl: TcaoCommitmentControl;
    FdateFormat: TcaoDateFormat;
    FdateSeparator: TcaoDateSeparator;
    FdecimalSeparator: TcaoDecimalSeparator;
    FignoreDecimalDataError: TcaoIgnoreDecimalDataError;
    FnamingConvention: TcaoNamingConvention;
    FtimeFormat: TcaoTimeFormat;
    FtimeSeparator: TcaoTimeSeparator;
    FcwbDatabaseConnection: cwbDatabaseConnection;
    FcaoErrorMessage: TcaoErrorMessage;
    FOnActive: TNotifyEvent;
    function GetConvert65535: WordBool;
    procedure SetConvert65535(Conv: WordBool);
    function GetCommitmentControl: TcaoCommitmentControl;
    procedure SetCommitmentControl(CommCtrl: TcaoCommitmentControl);
    function GetDateFormat: TcaoDateFormat;
    procedure SetDateFormat(DateFmt: TcaoDateFormat);
    function GetDateSeparator: TcaoDateSeparator;
    procedure SetDateSeparator(DateSep: TcaoDateSeparator);
    function GetDecimalSeparator: TcaoDecimalSeparator;
    procedure SetDecimalSeparator(DecSep: TcaoDecimalSeparator);
    function GetIgnoreDecimalDataError: TcaoIgnoreDecimalDataError;
    procedure SetIgnoreDecimalDataError(IgnoreErr: TcaoIgnoreDecimalDataError);
    function GetNamingConvention: TcaoNamingConvention;
    procedure SetNamingConvention(NamConv: TcaoNamingConvention);
    function GetTimeFormat: TcaoTimeFormat;
    procedure SetTimeFormat(TimeFmt: TcaoTimeFormat);
    function GetTimeSeparator: TcaoTimeSeparator;
    procedure SetTimeSeparator(TimeSep: TcaoTimeSeparator);
    function GetActive: Boolean;
    procedure SetActive(Value: Boolean);
  protected
    { Protected declarations }
    function ResultCodeText: String; virtual;
    function GetErrMsg: String; virtual;
    procedure Notification(AComponent: TComponent;
      Operation: TOperation); override;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure Setup; virtual;
    procedure SetClientDataCCSID(CCSID: ShortInt); virtual;
    procedure SetClientHostErrorCCSID(CCSID: ShortInt); virtual;
    procedure SetNLSS(NLSSTypeID: ShortInt; tableOrLangID: String; libraryName: String); virtual;
    procedure StartServer; virtual;
    procedure StartServerDetailed; virtual;
    procedure StopServer; virtual;
  published
    { Published declarations }
    property ReturnCode: Integer read FReturnCode default cwbOK;
    property Active: Boolean read GetActive write SetActive default false;
    property convert65535: WordBool read GetConvert65535 write SetConvert65535 default false;
    property commitmentControl: TcaoCommitmentControl read GetCommitmentControl write SetCommitmentControl default caodbNone;
    property dateFormat: TcaoDateFormat read GetDateFormat write SetDateFormat default caodbDateFmtISO;
    property dateSeparator: TcaoDateSeparator read GetDateSeparator write SetDateSeparator default caodbDateSepDash;
    property decimalSeparator: TcaoDecimalSeparator read GetDecimalSeparator write SetDecimalSeparator default caodbDecimalSepPeriod;
    property ignoreDecimalDataError: TcaoIgnoreDecimalDataError read GetIgnoreDecimalDataError write SetIgnoreDecimalDataError default caodbCorrectError;
    property namingConvention: TcaoNamingConvention read GetNamingConvention write SetNamingConvention default caodbSlashNameConv;
    property timeFormat: TcaoTimeFormat read GetTimeFormat write SetTimeFormat default caodbTimeFmtISO;
    property timeSeparator: TcaoTimeSeparator read GetTimeSeparator write SetTimeSeparator default caodbTimeSepPeriod;
    property systemName: String read FsystemName write FsystemName;
    property errorMessage: TcaoErrorMessage read FcaoErrorMessage write FcaoErrorMessage;
    property OleObject: cwbDatabaseConnection read FcwbDatabaseConnection;
    property OnActive: TNotifyEvent read FOnActive write FOnActive;
  end;

implementation

{
Create OLE object and initilize properties.
}

constructor TcaoDatabaseConnection.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FcwbDatabaseConnection := CocwbDatabaseConnection.Create;
  FActive := false;
  FSetupCalled := false;
  Fconvert65535 := false;
  FcommitmentControl := caodbNone;
  FdateFormat := caodbDateFmtISO;
  FdateSeparator := caodbDateSepDash;
  FdecimalSeparator := caodbDecimalSepPeriod;
  FignoreDecimalDataError := caodbCorrectError;
  FnamingConvention := caodbSlashNameConv;
  FtimeFormat := caodbTimeFmtISO;
  FtimeSeparator := caodbTimeSepPeriod
end;

{
End database server if active.
}

destructor TcaoDatabaseConnection.Destroy;
begin
  if FActive then
    SetActive(false);
  inherited Destroy;
end;

{
Return formatted result code text.
}

function TcaoDatabaseConnection.ResultCodeText: String;
begin
  Result := Format('Result code %d',[FReturnCode])
end;

{
Return error mesage or formatted result code text.
}

function TcaoDatabaseConnection.GetErrMsg: String;
var
  S: String;
begin
  S := FcaoErrorMessage.GetErrMsg;
  if S = '' then
    S := ResultCodeText;
  Result := S
end;

{
This property sets the indicator that says whether data that is marked with
CCSID 65535 is to be converted between ASCII and EBCDIC.  Data that is tagged
with CCSID 65535 is binary data. Selecting to convert this data may cause
conversion errors and possible data integrity problems. Use this property at
your own risk.

Having said that, it is important to note that some older data may have text
data that is tagged with CCSID 65535. Also, some AS/400 tools still write data
to files by using CCSID 65535. Therefore, there may be appropriate times to use
this property.

Get OLE property convert65535 if setup was called.  Otherwise, get private
variable.
}

function TcaoDatabaseConnection.GetConvert65535: WordBool;
begin
  if FSetupCalled then
    Result := FcwbDatabaseConnection.convert65535
  else
    Result := Fconvert65535
end;

{
Set OLE property convert65535 if setup was called. Otherwise, set private
variable.
}

procedure TcaoDatabaseConnection.SetConvert65535(Conv: WordBool);
begin
  if FSetupCalled then
    FcwbDatabaseConnection.convert65535 := Conv
  else
    Fconvert65535 := Conv
end;

{
This property contains the commitment level for the database server to use when
accessing data.  Possible values are:

cwbdbNone

  Provides no isolation from other application processes

  For a read-only cursor:

  Ensures the current row of every cursor is not changed by other application
  processes

  Ensures any row that was changed by another application process cannot be
  read until it is committed by that application process

  For a cursor that can be updated:

  A row that is changed can be immediately used or changed by other application
  processes

cwbdbCursorStability

  Ensures the current row of every cursor is not changed by other application
  processes

  Ensures any row that was changed by another application process cannot be
  read until it is committed by that application process.

cwbdddbChange

  For a read-only cursor:

  Allows any row that is read during the unit of work to be changed by other
  application processes.

  Allows any row that was changed by another application to be read, even if
  the change has not been committed by that application process.

  For a cursor that can be updated:

  Ensures the current row of every cursor is not changed by other application
  processes

  Ensures any row that was changed by another application process cannot be
  read until it is committed by that application process.

cwbdbAll

  Ensures any row that is read during a unit of work is not changed by other
  application processes until the unit of work is complete.

  Ensure any row that was changed by another application process cannot be read
  until it is committed by that application process

  This is a read/write property.  If this property is not set, cwbdbNone is
  used.

The cwbdbStartServer method must be called before setting or retrieving this
property.

Get OLE property commitmentControl if setup was called.  Otherwise, get private
variable.
}

function TcaoDatabaseConnection.GetCommitmentControl: TcaoCommitmentControl;
begin
  if FSetupCalled then
    case FcwbDatabaseConnection.commitmentControl of
      cwbdbNone:
        Result := caodbNone;
      cwbdbCursorStability:
        Result := caodbCursorStability;
      cwbdbChange:
        Result := caodbChange;
      cwbdbAll:
        Result := caodbAll
      else
        Result := caodbNone
    end
  else
    Result := FcommitmentControl
end;

{
Set OLE property commitmentControl if setup was called. Otherwise, set private
variable.
}

procedure TcaoDatabaseConnection.SetCommitmentControl(CommCtrl: TcaoCommitmentControl);
begin
  if FSetupCalled then
    case CommCtrl of
      caodbNone:
        FcwbDatabaseConnection.commitmentControl := cwbdbNone;
      caodbCursorStability:
        FcwbDatabaseConnection.commitmentControl := cwbdbCursorStability;
      caodbChange:
        FcwbDatabaseConnection.commitmentControl := cwbdbChange;
      caodbAll:
        FcwbDatabaseConnection.commitmentControl := cwbdbAll
    end
  else
    FcommitmentControl := CommCtrl
end;

{
This property contains the date format to be used by the database access
server.  Possible values are:

  cwbdbDateFmtJUL - Julian format - (yy/ddd)
  cwbdbDateFmtMDY - month/day/year format - (mm/dd/yy)
  cwbdbDateFmtDMY - day/month/year format - (dd/mm/yy)
  cwbdbDateFmtYMD - year/month/day format - (yy/mm/dd)
  cwbdbDateFmtUSA - USA standard format - (mm/dd/yyyy)
  cwbdbDateFmtISO - International Standards Organization format - (yyyy-mm-dd)
  cwbdbDateFmtJIS - Japanese industrial standard format - (yyyy-mm-dd)
  cwbdbDateFmtEUR - European standard format - (dd.mm.yyyy)

If this property is not set, the job's date format is used. This is a
read/write property.  The cwbdbStartServer method must be called before setting
or retrieving this property.

Get OLE property dateFormat if setup was called.  Otherwise, get private
variable.
}

function TcaoDatabaseConnection.GetDateFormat: TcaoDateFormat;
begin
  if FSetupCalled then
    case FcwbDatabaseConnection.dateFormat of
      cwbdbDateFmtJUL:
        Result := caodbDateFmtJUL;
      cwbdbDateFmtMDY:
        Result := caodbDateFmtMDY;
      cwbdbDateFmtDMY:
        Result := caodbDateFmtDMY;
      cwbdbDateFmtYMD:
        Result := caodbDateFmtYMD;
      cwbdbDateFmtUSA:
        Result := caodbDateFmtUSA;
      cwbdbDateFmtISO:
        Result := caodbDateFmtISO;
      cwbdbDateFmtJIS:
        Result := caodbDateFmtJIS;
      cwbdbDateFmtEUR:
        Result := caodbDateFmtEUR
      else
        Result := caodbDateFmtISO
    end
  else
    Result := FdateFormat
end;

{
Set OLE property dateFormat if setup was called. Otherwise, set private
variable.
}

procedure TcaoDatabaseConnection.SetDateFormat(DateFmt: TcaoDateFormat);
begin
  if FSetupCalled then
    case DateFmt of
      caodbDateFmtJUL:
        FcwbDatabaseConnection.dateFormat := cwbdbDateFmtJUL;
      caodbDateFmtMDY:
        FcwbDatabaseConnection.dateFormat := cwbdbDateFmtMDY;
      caodbDateFmtDMY:
        FcwbDatabaseConnection.dateFormat := cwbdbDateFmtDMY;
      caodbDateFmtYMD:
        FcwbDatabaseConnection.dateFormat := cwbdbDateFmtYMD;
      caodbDateFmtUSA:
        FcwbDatabaseConnection.dateFormat := cwbdbDateFmtUSA;
      caodbDateFmtISO:
        FcwbDatabaseConnection.dateFormat := cwbdbDateFmtISO;
      caodbDateFmtJIS:
        FcwbDatabaseConnection.dateFormat := cwbdbDateFmtJIS;
      caodbDateFmtEUR:
        FcwbDatabaseConnection.dateFormat := cwbdbDateFmtEUR
    end
  else
    FdateFormat := DateFmt
end;

{
This property contains the separator character to be used for the different
components of a date. Possible values are:

  cwbdbDateSepSlash,
  cwbdbDateSepDash,
  cwbdbDateSepPeriod,
  cwbdbDateSepComma, and
  cwbdbDateSepBlank.

If this property is not set, the job's date separator is used.  This is a
read/write property.  The cwbdbStartServer method must be called before setting
or retrieving this property.

Get OLE property dateSeparator if setup was called.  Otherwise, get private
variable.
}

function TcaoDatabaseConnection.GetDateSeparator: TcaoDateSeparator;
begin
  if FSetupCalled then
    case FcwbDatabaseConnection.dateSeparator of
      cwbdbDateSepSlash:
        Result := caodbDateSepSlash;
      cwbdbDateSepDash:
        Result := caodbDateSepDash;
      cwbdbDateSepPeriod:
        Result := caodbDateSepPeriod;
      cwbdbDateSepComma:
        Result := caodbDateSepComma;
      cwbdbDateSepBlank:
        Result := caodbDateSepBlank
      else
        Result := caodbDateSepSlash
    end
  else
    Result := FdateSeparator
end;

{
Set OLE property dateSeparator if setup was called. Otherwise, set private
variable.
}

procedure TcaoDatabaseConnection.SetDateSeparator(DateSep: TcaoDateSeparator);
begin
  if FSetupCalled then
    case DateSep of
      caodbDateSepSlash:
        FcwbDatabaseConnection.dateSeparator := cwbdbDateSepSlash;
      caodbDateSepDash:
        FcwbDatabaseConnection.dateSeparator := cwbdbDateSepDash;
      caodbDateSepPeriod:
        FcwbDatabaseConnection.dateSeparator := cwbdbDateSepPeriod;
      caodbDateSepComma:
        FcwbDatabaseConnection.dateSeparator := cwbdbDateSepComma;
      caodbDateSepBlank:
        FcwbDatabaseConnection.dateSeparator := cwbdbDateSepBlank
    end
  else
    FdateSeparator := DateSep
end;

{
This property contains the separator character to be used to divide the
fractional and non-fractional parts of a decimal number.  Possible values are:

  cwbdbDecimalSepPeriod and
  cwbdbDecimalSepComma

If this property is not set, cwbdbDecimalSepPeriod is used.  This is a
read/write property.  The cwbdbStartServer method must be called before
setting or retrieving this property.

Get OLE property decimalSeparator if setup was called.  Otherwise, get private
variable.
}

function TcaoDatabaseConnection.GetdecimalSeparator: TcaoDecimalSeparator;
begin
  if FSetupCalled then
    case FcwbDatabaseConnection.decimalSeparator of
      cwbdbDecimalSepPeriod:
        Result := caodbDecimalSepPeriod;
      cwbdbDecimalSepComma:
        Result := caodbDecimalSepComma
      else
        Result := caodbDecimalSepPeriod
    end
  else
    Result := FdecimalSeparator
end;

{
Set OLE property decimalSeparator if setup was called. Otherwise, set private
variable.
}

procedure TcaoDatabaseConnection.SetdecimalSeparator(DecSep: TcaoDecimalSeparator);
begin
  if FSetupCalled then
    case DecSep of
      caodbDecimalSepPeriod:
        FcwbDatabaseConnection.decimalSeparator := cwbdbDecimalSepPeriod;
      caodbDecimalSepComma:
        FcwbDatabaseConnection.decimalSeparator := cwbdbDecimalSepComma
    end
  else
    FdecimalSeparator := DecSep
end;

{
This property indicates whether to ignore or correct zoned decimal data errors.
Possible values are:

  cwbdbIgnoreError and
  cwbdbCorrectError

This is a read/write property.  If this property is not set, cwbdbCorrectError
is used.  The cwbdbStartServer method must be called before setting or
retrieving this property.

Get OLE property ignoreDecimalDataError if setup was called.  Otherwise, get private
variable.
}

function TcaoDatabaseConnection.GetignoreDecimalDataError: TcaoIgnoreDecimalDataError;
begin
  if FSetupCalled then
    case FcwbDatabaseConnection.ignoreDecimalDataError of
      cwbdbIgnoreError:
        Result := caodbIgnoreError;
      cwbdbCorrectError:
        Result := caodbCorrectError
      else
        Result := caodbCorrectError
    end
  else
    Result := FignoreDecimalDataError
end;

{
Set OLE property ignoreDecimalDataError if setup was called. Otherwise, set private
variable.
}

procedure TcaoDatabaseConnection.SetIgnoreDecimalDataError(IgnoreErr: TcaoIgnoreDecimalDataError);
begin
  if FSetupCalled then
    case IgnoreErr of
      caodbIgnoreError:
        FcwbDatabaseConnection.ignoreDecimalDataError := cwbdbIgnoreError;
      caodbCorrectError:
        FcwbDatabaseConnection.ignoreDecimalDataError := cwbdbCorrectError
    end
  else
    FignoreDecimalDataError := IgnoreErr
end;

{
This property contains the naming convention to be used by the database access
server.  Possible values are:

  cwbdbSlashNameConv (for native AS/400 naming convention) and
  cwbdbPeriodNameConv (for SQL naming convention).

If this property is not set, cwbdbSlashNameConv is used.  This is a read/write
property.  The cwbdbStartServer method must be called before setting or
retrieving this property.

Get OLE property namingConvention if setup was called.  Otherwise, get private
variable.
}

function TcaoDatabaseConnection.GetNamingConvention: TcaoNamingConvention;
begin
  if FSetupCalled then
    case FcwbDatabaseConnection.namingConvention of
      cwbdbPeriodNameConv:
        Result := caodbPeriodNameConv;
      cwbdbSlashNameConv:
        Result := caodbSlashNameConv
      else
        Result := caodbSlashNameConv
    end
  else
    Result := FnamingConvention
end;

{
Set OLE property namingConvention if setup was called. Otherwise, set private
variable.
}

procedure TcaoDatabaseConnection.SetNamingConvention(NamConv: TcaoNamingConvention);
begin
  if FSetupCalled then
    case NamConv of
      caodbPeriodNameConv:
        FcwbDatabaseConnection.namingConvention := cwbdbPeriodNameConv;
      caodbSlashNameConv:
        FcwbDatabaseConnection.namingConvention := cwbdbSlashNameConv
    end
  else
    FnamingConvention := NamConv
end;

{
This property contains the time format to be used by the database access
server.  Possible values are:

  cwbdbTimeFmtHMS - hour/minute/second format - (hh:mm:ss)
  cwbdbTimeFmtUSA - USA standard format - (hh:mm AM or PM)
  cwbdbTimeFmtISO - International Standards Organization format  -(hh.mm.ss)
  cwbdbTimeFmtEUR - European standard format - (hh.mm.ss)
  cwbdbTimeFmtJIS - Japanese industrial standard format - (hh:mm:ss)

If this property is not set, cwbdbTimeFmtHMS is used.  This is a read-write
property.  The cwbdbStartServer method must be called before setting or
retrieving this property.

Get OLE property timeFormat if setup was called.  Otherwise, get private
variable.
}

function TcaoDatabaseConnection.GetTimeFormat: TcaoTimeFormat;
begin
  if FSetupCalled then
    case FcwbDatabaseConnection.timeFormat of
      cwbdbTimeFmtHMS:
        Result := caodbTimeFmtHMS;
      cwbdbTimeFmtUSA:
        Result := caodbTimeFmtUSA;
      cwbdbTimeFmtISO:
        Result := caodbTimeFmtISO;
      cwbdbTimeFmtEUR:
        Result := caodbTimeFmtEUR;
      cwbdbTimeFmtJIS:
        Result := caodbTimeFmtJIS
      else
        Result := caodbTimeFmtISO
    end
  else
    Result := FtimeFormat
end;

{
Set OLE property timeFormat if setup was called. Otherwise, set private
variable.
}

procedure TcaoDatabaseConnection.SetTimeFormat(TimeFmt: TcaoTimeFormat);
begin
  if FSetupCalled then
    case TimeFmt of
      caodbTimeFmtHMS:
        FcwbDatabaseConnection.timeFormat := cwbdbTimeFmtHMS;
      caodbTimeFmtUSA:
        FcwbDatabaseConnection.timeFormat := cwbdbTimeFmtUSA;
      caodbTimeFmtISO:
        FcwbDatabaseConnection.timeFormat := cwbdbTimeFmtISO;
      caodbTimeFmtEUR:
        FcwbDatabaseConnection.timeFormat := cwbdbTimeFmtEUR;
      caodbTimeFmtJIS:
        FcwbDatabaseConnection.timeFormat := cwbdbTimeFmtJIS
    end
  else
    FtimeFormat := TimeFmt
end;

{
This property contains the separator character to be used for the different
components of a time.  Possible values are:

  cwbdbTimeSepColon,
  cwbdbTimeSepPeriod,
  cwbdbTimeSepComma, and
  cwbdbTimeSepBlank.

If this property is not set, the job's time separator is used. This is a
read-write property.  The cwbdbStartServer method must be called before
setting or retrieving this property.

Get OLE property timeSeparator if setup was called.  Otherwise, get private
variable.
}

function TcaoDatabaseConnection.GetTimeSeparator: TcaoTimeSeparator;
begin
  if FSetupCalled then
    case FcwbDatabaseConnection.timeSeparator of
      cwbdbTimeSepColon:
        Result := caodbTimeSepColon;
      cwbdbTimeSepPeriod:
        Result := caodbTimeSepPeriod;
      cwbdbTimeSepComma:
        Result := caodbTimeSepComma;
      cwbdbTimeSepBlank:
        Result := caodbTimeSepBlank
      else
        Result := caodbTimeSepColon
    end
  else
    Result := FtimeSeparator
end;

{
Set OLE property timeSeparator if setup was called. Otherwise, set private
variable.
}

procedure TcaoDatabaseConnection.SetTimeSeparator(TimeSep: TcaoTimeSeparator);
begin
  if FSetupCalled then
    case TimeSep of
      caodbTimeSepColon:
        FcwbDatabaseConnection.timeSeparator := cwbdbTimeSepColon;
      caodbTimeSepPeriod:
        FcwbDatabaseConnection.timeSeparator := cwbdbTimeSepPeriod;
      caodbTimeSepComma:
        FcwbDatabaseConnection.timeSeparator := cwbdbTimeSepComma;
      caodbTimeSepBlank:
        FcwbDatabaseConnection.timeSeparator := cwbdbTimeSepBlank
    end
  else
    FtimeSeparator := TimeSep
end;

{
Return Active value.
}

function TcaoDatabaseConnection.GetActive: Boolean;
begin
  Result := FActive
end;

{
Set Active value and start or stop connection based on value.
}

procedure TcaoDatabaseConnection.SetActive(Value: Boolean);
begin
  if not FSetupCalled then
    Setup;
  if Value = true then
    StartServer
  else
    StopServer;
  FActive := Value;
  if FActive then
    if Assigned(OnActive) then
    OnActive(Self)
end;

{
Handle caoErrorMessage component being removed.
}

procedure TcaoDatabaseConnection.Notification(AComponent: TComponent;
  Operation: TOperation);
begin
  inherited Notification(AComponent, Operation);
  if (Operation = opRemove) and
  (AComponent = FcaoErrorMessage) then
      FcaoErrorMessage := nil
end;

{
This method initializes the object.  It must be called before any other method
or before accessing any of the objects properties.
}

procedure TcaoDatabaseConnection.Setup;
begin
  FReturnCode := FcwbDatabaseConnection.cwbdbSetup(FsystemName,
  FcaoErrorMessage.OleObject);
  // Raise exception if needed
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseConnection.Create(ResultCodeText);
  FSetupCalled := true;
  // Set OLE properties from variables
  SetConvert65535(Fconvert65535)
end;

{
This method sets the CCSID (Coded Character Set ID) for the client.  The new
CCSID value will be used when converting EBCDIC data from the AS/400.

To set the CCSID that is used when converting host error information, use the
cwbDB_SetClientHostErrorCCSID method.

If this method is not called, the OEM code page is used.
}

procedure TcaoDatabaseConnection.SetClientDataCCSID(CCSID: ShortInt);
begin
  FReturnCode := FcwbDatabaseConnection.cwbdbSetClientDataCCSID(
  CCSID,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseConnection.Create(GetErrMsg)
end;

{
This method sets the CCSID (Coded Character Set ID) for the client.  The new
CCSID value will be used when converting EBCDIC server messages.

To set the CCSID that is used for converting data, use the
cwbDB_SetClientDataCCSID method.

If this method is not called, the OEM code page is used.
}

procedure TcaoDatabaseConnection.SetClientHostErrorCCSID(CCSID: ShortInt);
begin
  FReturnCode := FcwbDatabaseConnection.cwbdbSetClientHostErrorCCSID(
  CCSID,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseConnection.Create(GetErrMsg)
end;

{
This method sets the National Language Sort Sequence (NLSS) to be used by the
data access server.  If this method is not called, sorting is done by
hexadecimal value.

Parameters:

NLSSTypeID - Short Integer

NLSSTypeID specifies the type of sort sequence to use.  Possible values are:
cwbdbHexSort, cwbdbSharedSort, cwbdbUniqueSort, and cwbdbUserSort.

tableOrLangID - String

If NLSSTypeID is cwbdbHexSort, this parameter is not used.  If NLSSTypeID is
cwbdbSharedSort or cwbdbUniqueSort, this parameter represents the language
feature code ID.  If NLSSTypeID is cwbdbUserSort, this parameter represents
the table contaning the user-defined sort sequence.

libraryName - String

If NLSSTypeID is cwbdbUserSort, this parameter represents the library
containing the table with the user-defined sort sequence.  If NLSSTypeID is
cwbdbHexSort, cwbdbSharedSort, or cwbdbUnique, this parameter is not used.

errorMessage - Object

A cwbErrorMessage object which is used to hold any error messages.  If the
cwbdbSetNLSS request fails, the properties and methods of the errorMessage
object can be used to determine what went wrong.  Before cwbdbSetNLSS is
called, the cwbsvSetup method must be called on the errorMessage object.
}

procedure TcaoDatabaseConnection.SetNLSS(NLSSTypeID: ShortInt;
tableOrLangID: String; libraryName: String);
begin
  FReturnCode := FcwbDatabaseConnection.cwbdbSetNLSS(
  NLSSTypeID,tableOrLangID,libraryName,FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseConnection.Create(GetErrMsg)
end;

{
This method  starts communications between the client and the AS/400 database
server.  Some OLE properties cannot be initilized until Setup is call, so they
are initilized here.
}

procedure TcaoDatabaseConnection.StartServer;
begin
  FReturnCode := FcwbDatabaseConnection.cwbdbStartServer(
  FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseConnection.Create(GetErrMsg);
  // Set OLE properties from variables
  SetCommitmentControl(FcommitmentControl);
  SetDateFormat(FdateFormat);
  SetDateSeparator(FdateSeparator);
  SetDecimalSeparator(FdecimalSeparator);
  SetIgnoreDecimalDataError(FignoreDecimalDataError);
  SetNamingConvention(FnamingConvention);
  SetTimeFormat(FtimeFormat);
  SetTimeSeparator(FtimeSeparator)
end;

{
This method starts the communication between the client and the AS/400 server.
It returns a more detailed return code than the cwbdbStartServer method,
otherwise it is the same as cwbdbStartServer.
}

procedure TcaoDatabaseConnection.StartServerDetailed;
begin
  FReturnCode := FcwbDatabaseConnection.cwbdbStartServerDetailed(
  FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseConnection.Create(GetErrMsg)
end;

{
This method stops communications between the client and the AS/400 database
server.
}

procedure TcaoDatabaseConnection.StopServer;
begin
  FReturnCode := FcwbDatabaseConnection.cwbdbStopServer(
  FcaoErrorMessage.OleObject);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoDatabaseConnection.Create(GetErrMsg)
end;

end.
